# Multiobjective test functions used to verify TS-EMO

This folder contains the test functions kno1, vlmop2, vlmop3, oka1, oka2, dtlz1a, dtlz2a, dtlz4a and dtlz7a, which were taken from https://www.cs.bham.ac.uk/~jdk/parego/ParEGO-TR3.pdf.

For more information on the test functions please refer to https://www.cs.bham.ac.uk/~jdk/parego/ParEGO-TR3.pdf.
